@@ -259,8 +259,9 @@ Q.tags_input = function(elem, options) {
       inp.placeholder = options.placeholder;
       inp.setAttribute('list',  options.autocomplete_list);
       inp.onchange = function(evt) {
-        inp.value.split(',').map(function(x){ 
-          x = options.transform(x.trim());
+        inp.value.split(',').map(function(x){
+	  x = options.transform(x.trim());
+	  if (options.regex && !x.match(options.regex)) return;
           if (x && tags.indexOf(x)<0) tags.push(x); 
           if (x && keys.indexOf(x)<0) keys.push(x); 
         });
@@ -369,4 +370,5 @@ Q.handle_flash = function() {
 Q.handle_components();
 Q.handle_flash();
 Q('input[type=text].type-list-string').forEach(function(elem){Q.tags_input(elem);});
+Q('input[type=text].type-list-integer').forEach(function(elem){Q.tags_input(elem, {regex:/[-+]?[\d]+/});});
 Q('input[name=password],input[name=new_password]').forEach(Q.score_input);
