@@ -35,7 +35,6 @@ import urllib.parse
 import uuid
 import zipfile
 import asyncio
-import zipfile
 from watchgod import awatch
 
 # Optional web servers for speed
@@ -128,6 +127,22 @@ def module2filename(module):
     return filename
 
 
+########################################################################################
+# fix request.fullpath for the case of domain mapping to app
+# (request.url will be autofixed, since it is based on request.fullpath)
+#########################################################################################
+def monkey_patch_bottle():
+    urljoin = urllib.parse.urljoin
+    @property
+    def fullpath(self):
+        appname = self.get_header('x-py4web-appname', '/')
+        return urljoin(self.script_name, self.path[len(appname):])
+    setattr(bottle.BaseRequest, 'fullpath', fullpath)
+
+
+monkey_patch_bottle()
+
+
 ########################################################################################
 # Implement a O(1) LRU cache and memoize with expiration and monitoring (using linked list)
 #########################################################################################
@@ -327,12 +342,12 @@ ICECUBE = {}
 
 class Flash(Fixture):
     """
-    flash = Flash(session)
-    
-    #acton('index.html')
+    flash = Flash()
+
+    @action('index')
     @action.uses(flash)
     def index():
-        flash.set('hello', class_='important')        
+        flash.set('hello', class_='important')
         return dict()
 
     Flash messages are added to the dict and, upon redirect, carry forward
@@ -672,8 +687,7 @@ class action:
         while stack:
             fixture = stack.pop()
             reversed_fixtures.append(fixture)
-            for other in getattr(fixture, "__prerequisites__", []):
-                stack.append(other)
+            stack.extend(getattr(fixture, "__prerequisites__", ()))
         for fixture in reversed(reversed_fixtures):
             if isinstance(fixture, str):
                 fixture = Template(fixture)
@@ -1307,7 +1321,7 @@ def install_args(args, reinstall_apps=False):
             click.echo("Command aborted")
             sys.exit(0)
 
-    # Upzip the _dashboard app if it is old or does not exist
+    # Reinstall apps from zipped ones in assets
     if reinstall_apps:
         assets_dir = os.path.join(os.path.dirname(__file__), "assets")
         if os.path.exists(assets_dir):
@@ -1321,11 +1335,9 @@ def install_args(args, reinstall_apps=False):
                 if not os.path.exists(target_dir):
                     if yes or click.confirm("Create app %s?" % app_name):
                         click.echo("[ ] Unzipping app %s" % filename)
-                        zip_file = zipfile.ZipFile(zip_filename, "r")
-                        if not os.path.exists(target_dir):
+                        with zipfile.ZipFile(zip_filename, "r") as zip_file:
                             os.makedirs(target_dir)
                             zip_file.extractall(target_dir)
-                            zip_file.close()
                             click.echo("\x1b[A[X]")
 
     if not os.path.exists(args["service_folder"]):
@@ -1512,14 +1524,15 @@ def new_app(apps_folder, app_name, scaffold_zip):
     "-d",
     "--dashboard_mode",
     default="full",
-    help="Dashboard mode: demo, readonly, full (default), none",
+    help="Dashboard mode: demo, readonly, full, none",
     show_default=True,
 )
 @click.option(
     "--watch",
     default="off",
     type=click.Choice(["off", "sync", "lazy"]),
-    help="Watch python changes and reload apps automatically, modes: off (default), sync, lazy",
+    help="Watch python changes and reload apps automatically, modes: off, sync, lazy",
+    show_default=True,
 )
 @click.option(
     "--ssl_cert", type=click.Path(exists=True), help="SSL certificate file for HTTPS"
