@@ -5,10 +5,21 @@ from functools import wraps
 import jwt
 from yatl.helpers import TAG
 from py4web import action, URL, request
-from py4web.core import dumps, Session
+from py4web.core import dumps, Session, Fixture
+
+class Inject(Fixture):
+
+    def __init__(self, **variables):
+        self.variables = variables
+
+    def transform(self, output, shared_data=None):
+        if isinstance(output, dict):
+            output.update(**self.variables)
+        return output
 
 
 class ActionFactory:
+
     def __init__(self, *fixtures):
         self.fixtures = fixtures
 
@@ -27,8 +38,8 @@ class ActionFactory:
     def head(self, path=None, template=None):
         return self._action_maker("HEAD", path, template)
 
-    def __call__(self, path=None, template=None):
-        return self._action_maker(["GET", "POST", "PUT", "DELETE"], path, template)
+    def __call__(self, path=None, template=None, method=['GET', 'POST', 'PUT', 'HEAD', 'DELETE']):
+        return self._action_maker(method, path, template)
 
     def _action_maker(self, method, path, template):
         def make_action(func, path=path, method=method, template=template):
